@@ -48,17 +48,17 @@ options = get_options()
 
 
 def dryrun(input_iter):
-    """Iterator added to the pipeline when user only wants
-    a dry run, listing all of the discovered tests but not
-    actually running them.
+    """Iterator added to the pipeline when user only wants a dry run, listing specs for all of the
+    discovered tests but not actually running them.
     """
     for tests in input_iter:
         for test in tests:
             if test.status is None:
                 test.status = 'OK'
-            print(test)
+            print(test.spec)
             yield test
 
+
 def run_pipeline(source, pipe):
     """Run a pipeline of test iteration objects."""
 
@@ -140,9 +140,14 @@ skip_dirs=site-packages,
         options.test_glob = ['test*']
 
     def func_matcher(funcname):
+        for pattern in options.excludes:
+            if fnmatchcase(funcname, pattern):
+                return False
+
         for pattern in options.test_glob:
             if fnmatchcase(funcname, pattern):
                 return True
+
         return False
 
     if options.benchmark:
